==> openturns_1.3.orig.tar.bz2: openturns-1.3/lib/test/t_NumericalMathFunction_exec_threads.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_NumericalMathFunction_exec_threads.cxx
 *  @brief The test file of class NumericalMathFunction for standard methods
 *
 *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author schueller
 *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try
  {

    /** Instance creation */
    NumericalMathFunction external("external_code_threads");

    UnsignedLong size(20);
    UnsignedLong dimension(external.getInputDimension());
    NumericalSample sample(size, dimension);
    for (UnsignedLong i = 0; i < size; i++)
    {
      for (UnsignedLong j = 0; j < dimension; j++)
      {
        sample[i][j] = NumericalScalar(i + j) / (size + dimension);
      }
    }

    fullprint << "external code(sample) = " << external(sample) << std::endl;

  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_1.5.orig.tar.bz2: openturns-1.5/lib/test/t_NumericalMathFunction_exec_threads.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_NumericalMathFunction_exec_threads.cxx
 *  @brief The test file of class NumericalMathFunction for standard methods
 *
 *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author schueller
 *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try
  {

    /** Instance creation */
    NumericalMathFunction external("external_code_threads");

    UnsignedInteger size(20);
    UnsignedInteger dimension(external.getInputDimension());
    NumericalSample sample(size, dimension);
    for (UnsignedInteger i = 0; i < size; i++)
    {
      for (UnsignedInteger j = 0; j < dimension; j++)
      {
        sample[i][j] = NumericalScalar(i + j) / (size + dimension);
      }
    }

    fullprint << "external code(sample) = " << external(sample) << std::endl;

  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
